@@ -92,10 +92,14 @@ marginal_smooths_internal.btl <- function(x, fit, samples, smooths,
   stopifnot(is.brmsfit(fit))
   out <- list()
   mf <- model.frame(fit)
-  too_many_covars <- FALSE
   smef <- tidy_smef(x, mf)
-  smterms <- unique(smef$term) 
-  for (i in seq_along(smterms)) {
+  smterms <- unique(smef$term)
+  if (!length(smooths)) {
+    I <- seq_along(smterms)
+  } else {
+    I <- which(smterms %in% smooths)
+  }
+  for (i in I) {
     # loop over smooth terms and compute their predictions
     term <- smterms[i]
     sub_smef <- subset2(smef, term = term)
@@ -104,86 +108,82 @@ marginal_smooths_internal.btl <- function(x, fit, samples, smooths,
     vars <- sub_smef$vars[[1]]
     ncovars <- length(covars)
     if (ncovars > 2L) {
-      too_many_covars <- TRUE
+      byvars <- c(covars[3:ncovars], byvars)
+      covars <- covars[1:2]
+      ncovars <- 2L
     }
-    include_smooth <- !length(smooths) || term %in% smooths
-    if (include_smooth && !too_many_covars) {
-      values <- named_list(vars)
-      for (cv in covars) {
-        if (is.numeric(mf[[cv]])) {
-          values[[cv]] <- seq(
-            min(mf[[cv]]), max(mf[[cv]]), 
-            length.out = resolution
-          )
-        } else {
-          values[[cv]] <- levels(factor(mf[[cv]]))
-        }
-      }
-      for (cv in byvars) {
-        if (cv %in% names(int_conditions)) {
-          values[[cv]] <- int_conditions[[cv]]
-        } else if (is.numeric(mf[[cv]])) {
-          mean2 <- mean(mf[[cv]], na.rm = TRUE)
-          sd2 <- sd(mf[[cv]], na.rm = TRUE)
-          values[[cv]] <- (-1:1) * sd2 + mean2
-        } else {
-          values[[cv]] <- levels(factor(mf[[cv]]))
-        }
-      }
-      newdata <- expand.grid(values)
-      if (ncovars == 2L && too_far > 0) {
-        # exclude prediction grid points too far from data
-        ex_too_far <- mgcv::exclude.too.far(
-          g1 = newdata[[covars[1]]], 
-          g2 = newdata[[covars[2]]], 
-          d1 = mf[, covars[1]],
-          d2 = mf[, covars[2]],
-          dist = too_far
+    values <- named_list(vars)
+    is_numeric <- setNames(rep(FALSE, ncovars), covars)
+    for (cv in covars) {
+      if (is.numeric(mf[[cv]])) {
+        is_numeric[cv] <- TRUE
+        values[[cv]] <- seq(
+          min(mf[[cv]]), max(mf[[cv]]), 
+          length.out = resolution
         )
-        newdata <- newdata[!ex_too_far, ]  
+      } else {
+        values[[cv]] <- levels(factor(mf[[cv]]))
       }
-      other_vars <- setdiff(names(conditions), vars)
-      newdata[, other_vars] <- conditions[1, other_vars]
-      sdata <- standata(
-        fit, newdata, re_formula = NA, 
-        internal = TRUE, check_response = FALSE
-      )
-      draws_args <- nlist(x, samples, sdata, data = mf, smooths_only = TRUE)
-      draws <- do.call(extract_draws, draws_args)
-      J <- which(smef$termnum == i)
-      scs <- unlist(attr(draws$fe$X, "smcols")[J])
-      draws$fe$X <- draws$fe$X[, scs, drop = FALSE]
-      draws$fe$b <- draws$fe$b[, scs, drop = FALSE]
-      draws$sm <- draws$sm[J]
-      eta <- predictor(draws, i = NULL)
-      spa_data <- NULL
-      if (spaghetti && ncovars == 1L) {
-        sample <- rep(seq_rows(eta), each = ncol(eta))
-        spa_data <- data.frame(as.numeric(t(eta)), factor(sample))
-        colnames(spa_data) <- c("estimate__", "sample__")
-        spa_data <- cbind(newdata[, vars, drop = FALSE], spa_data)
-      }
-      eta <- posterior_summary(eta, robust = TRUE, probs = probs)
-      colnames(eta) <- c("estimate__", "se__", "lower__", "upper__")
-      eta <- cbind(newdata[, vars, drop = FALSE], eta)
-      if (length(byvars)) {
-        # byvars will be plotted as facets
-        bynumeric <- byvars[ulapply(eta[byvars], is.numeric)]
-        for (cv in bynumeric) {
-          eta[[cv]] <- round(eta[[cv]], 2)
-        }
-        eta$cond__ <- Reduce(paste_colon, eta[, byvars, drop = FALSE]) 
-      }
-      response <- combine_prefix(x, keep_mu = TRUE)
-      response <- paste0(response, ": ", term)
-      attr(eta, "response") <- response
-      attr(eta, "effects") <- covars
-      attr(eta, "surface") <- ncovars == 2L
-      attr(eta, "spaghetti") <- spa_data
-      attr(eta, "points") <- mf[, vars, drop = FALSE]
-      attr(eta, "too_many_covars") <- too_many_covars
-      out[[response]] <- eta
     }
+    for (cv in byvars) {
+      if (cv %in% names(int_conditions)) {
+        values[[cv]] <- int_conditions[[cv]]
+      } else if (is.numeric(mf[[cv]])) {
+        mean2 <- mean(mf[[cv]], na.rm = TRUE)
+        sd2 <- sd(mf[[cv]], na.rm = TRUE)
+        values[[cv]] <- (-1:1) * sd2 + mean2
+      } else {
+        values[[cv]] <- levels(factor(mf[[cv]]))
+      }
+    }
+    newdata <- expand.grid(values)
+    if (ncovars == 2L && too_far > 0) {
+      # exclude prediction grid points too far from data
+      ex_too_far <- mgcv::exclude.too.far(
+        g1 = newdata[[covars[1]]], 
+        g2 = newdata[[covars[2]]], 
+        d1 = mf[, covars[1]],
+        d2 = mf[, covars[2]],
+        dist = too_far
+      )
+      newdata <- newdata[!ex_too_far, ]  
+    }
+    other_vars <- setdiff(names(conditions), vars)
+    newdata[, other_vars] <- conditions[1, other_vars]
+    sdata <- standata(
+      fit, newdata, re_formula = NA, 
+      internal = TRUE, check_response = FALSE
+    )
+    draws_args <- nlist(x, samples, sdata, data = mf, smooths_only = TRUE)
+    draws <- do.call(extract_draws, draws_args)
+    J <- which(smef$termnum == i)
+    scs <- unlist(attr(draws$sm$fe$Xs, "smcols")[J])
+    draws$sm$fe$Xs <- draws$sm$fe$Xs[, scs, drop = FALSE]
+    draws$sm$fe$bs <- draws$sm$fe$bs[, scs, drop = FALSE]
+    draws$sm$re <- draws$sm$re[J]
+    eta <- predictor(draws, i = NULL)
+    spa_data <- NULL
+    if (spaghetti && ncovars == 1L && is_numeric[1]) {
+      sample <- rep(seq_rows(eta), each = ncol(eta))
+      spa_data <- data.frame(as.numeric(t(eta)), factor(sample))
+      colnames(spa_data) <- c("estimate__", "sample__")
+      spa_data <- cbind(newdata[, vars, drop = FALSE], spa_data)
+    }
+    eta <- posterior_summary(eta, robust = TRUE, probs = probs)
+    colnames(eta) <- c("estimate__", "se__", "lower__", "upper__")
+    eta <- cbind(newdata[, vars, drop = FALSE], eta)
+    if (length(byvars)) {
+      # byvars will be plotted as facets
+      eta$cond__ <- rows2labels(eta[, byvars, drop = FALSE]) 
+    }
+    response <- combine_prefix(x, keep_mu = TRUE)
+    response <- paste0(response, ": ", term)
+    attr(eta, "response") <- response
+    attr(eta, "effects") <- covars
+    attr(eta, "surface") <- all(is_numeric) && ncovars == 2L
+    attr(eta, "spaghetti") <- spa_data
+    attr(eta, "points") <- mf[, vars, drop = FALSE]
+    out[[response]] <- eta
   }
   out
 }
